@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: main.c 569 2004-04-10 07:41:12Z roms $ */
+/* $Id: main.c 697 2004-05-11 12:16:35Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -196,7 +196,7 @@ int APIENTRY WinMain(HINSTANCE hInstance,
 	/* Check whether a TiLP session is already running */
 	hMutex = CreateMutex(NULL, TRUE, "TiLP");
 	if (GetLastError() == ERROR_ALREADY_EXISTS) {
-		g_error("WinMain: TiLP is already running.");
+		MessageBox(NULL, _("An TiLP session is already running. Check the task list."), _("Error"), MB_OK);
 	}
 
 	return main(__argc, __argv, NULL);
