@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: manpage.c 443 2004-04-03 13:31:55Z roms $ */
+/* $Id: manpage.c 710 2004-05-14 14:37:42Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -83,9 +83,6 @@ gint display_manpage_dbox()
 	gtk_widget_show(dbox);
 	//gtk_window_resize(GTK_WINDOW(dbox), 640, 480);
 
-	while (gtk_events_pending())
-		gtk_main_iteration();
-
 	result = gtk_dialog_run(GTK_DIALOG(dbox));
 	switch (result) {
 	case GTK_RESPONSE_OK:
