@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: scroptions.c 366 2004-03-22 18:04:07Z roms $ */
+/* $Id: scroptions.c 710 2004-05-14 14:37:42Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -89,9 +89,6 @@ gint display_scroptions_dbox()
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data),
 					     FALSE);
 
-	while (gtk_events_pending())
-		gtk_main_iteration();
-
 	result = gtk_dialog_run(GTK_DIALOG(dbox));
 	switch (result) {
 	case GTK_RESPONSE_OK:
