@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_main.c 575 2004-04-10 15:28:49Z roms $ */
+/* $Id: tilp_main.c 786 2004-09-18 17:32:29Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -191,12 +191,16 @@ int scan_cmdline(int argc, const char **argv)
 				options.lp.calc_type = CALC_TI92P;
 			if (!strcmp(q, "ti92"))
 				options.lp.calc_type = CALC_TI92;
+			if (!strcmp(q, "ti89t"))
+				options.lp.calc_type = CALC_TI89T;
 			if (!strcmp(q, "ti89"))
 				options.lp.calc_type = CALC_TI89;
 			if (!strcmp(q, "ti86"))
 				options.lp.calc_type = CALC_TI86;
 			if (!strcmp(q, "ti85"))
 				options.lp.calc_type = CALC_TI85;
+			if (!strcmp(q, "ti84+"))
+				options.lp.calc_type = CALC_TI84P;
 			if (!strcmp(q, "ti83+"))
 				options.lp.calc_type = CALC_TI83P;
 			if (!strcmp(q, "ti83"))
