@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_rcfile.c 558 2004-04-09 14:15:30Z roms $ */
+/* $Id: tilp_rcfile.c 786 2004-09-18 17:32:29Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -153,6 +153,9 @@ void tilp_rcfile_read(void)
 			else if (!strcmp(p, "ti92"))
 				options.lp.calc_type = CALC_TI92;
 
+			else if (!strcmp(p, "ti89t"))
+				options.lp.calc_type = CALC_TI89T;
+
 			else if (!strcmp(p, "ti89"))
 				options.lp.calc_type = CALC_TI89;
 
@@ -162,6 +165,9 @@ void tilp_rcfile_read(void)
 			else if (!strcmp(p, "ti85"))
 				options.lp.calc_type = CALC_TI85;
 
+			else if (!strcmp(p, "ti84+"))
+				options.lp.calc_type = CALC_TI84P;
+
 			else if (!strcmp(p, "ti83+"))
 				options.lp.calc_type = CALC_TI83P;
 
@@ -203,6 +209,9 @@ void tilp_rcfile_read(void)
 			else if (!strcmp(p, "UsbGraphLink"))
 				options.lp.link_type = LINK_UGL;
 
+            else if (!strcmp(p, "null"))
+				options.lp.link_type = LINK_NUL;
+
 			else
 				stop(l);
 			continue;
@@ -282,6 +291,9 @@ void tilp_rcfile_read(void)
 			else if (!strcmp(p, "USB port #4"))
 				options.lp.port = USB_PORT_4;
 
+            else if (!strcmp(p, "null port"))
+				options.lp.port = NULL_PORT;
+
 			else
 				stop(l);
 			continue;
@@ -591,6 +603,9 @@ void tilp_rcfile_write(void)
 	case CALC_TI92:
 		fprintf(txt, "ti92\n");
 		break;
+	case CALC_TI89T:
+		fprintf(txt, "ti89t\n");
+		break;
 	case CALC_TI89:
 		fprintf(txt, "ti89\n");
 		break;
@@ -600,6 +615,9 @@ void tilp_rcfile_write(void)
 	case CALC_TI85:
 		fprintf(txt, "ti85\n");
 		break;
+	case CALC_TI84P:
+		fprintf(txt, "ti84+\n");
+		break;
 	case CALC_TI83P:
 		fprintf(txt, "ti83+\n");
 		break;
@@ -641,6 +659,9 @@ void tilp_rcfile_write(void)
 	case LINK_UGL:
 		fprintf(txt, "UsbGraphLink\n");
 		break;
+    case LINK_NUL:
+        fprintf(txt, "null\n");
+		break;
 	default:
 		fprintf(txt, "invalid\n");
 		break;
@@ -691,6 +712,9 @@ void tilp_rcfile_write(void)
 	case USB_PORT_4:
 		fprintf(txt, "USB port #4\n");
 		break;
+    case NULL_PORT:
+        fprintf(txt, "null port\n");
+		break;
 	default:
 		fprintf(txt, "invalid\n");
 		break;
