@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_struct.h 366 2004-03-22 18:04:07Z roms $ */
+/* $Id: tilp_struct.h 695 2004-05-11 07:01:45Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -32,15 +32,7 @@
 #endif				/* !__MACOSX__ */
 
 #include <sys/types.h>
-
-#ifndef __WIN32__
-# include <sys/stat.h>
-#endif
-
-#ifdef __WIN32__
-# include "win32/grp.h"
-# include "win32/pwd.h"
-#endif
+#include <sys/stat.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -63,6 +55,7 @@ extern "C" {
     gchar *icon_dir;		// icons
     gchar *plugin_dir;		// plug-ins
     gchar *glade_dir;		// directory of files for Glade
+    gchar *home_dir;		// $HOME
   } TilpInstPaths;
 #endif
 
@@ -128,9 +121,15 @@ extern "C" {
     char *name;
     time_t date;
     off_t size;
+#ifdef __WIN32__
+    int user;
+    int group;
+    int attrib;
+#else
     uid_t user;
     gid_t group;
     mode_t attrib;
+#endif
 
     char **actions;		// Ticalc action associated w/ the file
   } TilpFileInfo;
